% NewtonCotes
% ---------------------------------------------------------------------
% Algoritmo per il calcolo dell'integrale definito di una funzione
% mediante formule interpolatorie di Newton-Cotes
% ---------------------------------------------------------------------
% S = NewtonCotes(n,funzione,a,b)
% ---------------------------------------------------------------------
% Parametri di input
% n = grado della formula di quadratura
% funzione = nome della funzione da integrare
% x0, x1 = estremi dell'intervallo di integrazione
% ---------------------------------------------------------------------
% Parametri di output
% S = Valore calcolato dell'integrale della funzione in x0, x1
% ---------------------------------------------------------------------
function S = NewtonCotes(n,funzione,x0,x1) ;
% Coefficienti della formula
switch n
case 1
a = [1 1] / 2;
case 2
a = [1 4 1] / 3;
case 3
a = [3 9 9 3] / 8;
case 4
a = [14 64 24 64 14] / 45 ;
case 5
a = [95 375 250 250 375 95] / 288 ;
case 6
a = [41 216 27 272 27 216 41] / 140 ;
case 7
a = [5257 25039 9261 20923 20923 9261 25039 5257] / 17280 ;
end
% Calcolo dei nodi e distanza dei nodi
h = (x1 - x0)/n ;
x = linspace(x0,x1,n+1) ;
% Calcolo dell'integrale
S = 0 ;
for i = 1 : n+1
S = S + a(i)*feval(funzione,x(i)) ;
end
S = S * h ;