% TrapeziComposta
% ---------------------------------------------------------------------
% Algoritmo per il calcolo dell'integrale definito di una funzione
% mediante la formula composta dei Trapezi
% ---------------------------------------------------------------------
% [S,Err] = TrapeziComposta(N,funzione,a,b)
% ---------------------------------------------------------------------
% Parametri di input
% N = numero di sottointervalli della formula composta
% funzione = nome della funzione da integrare
% a, b = estremi dell'intervallo di integrazione
% ---------------------------------------------------------------------
% Parametri di output
% Sn = Valore calcolato dell'integrale della funzione in a, b
% Err = Errore assoluto rispetto all'integrale esatto
% ---------------------------------------------------------------------
function [Sn,Err] = TrapeziComposta(N,funzione,a,b) ;
% Calcolo degli estremi dei sottointervalli
z = linspace(a,b,N+1) ;
% Calcolo dell'integrale
Sn = feval(funzione,z(1)) + feval(funzione,z(N+1)) ;
for k = 1 : N
Sn = Sn + 2*feval(funzione,z(k)) ;
end
Sn = Sn * (b-a)/(2*N) ;
% Calcolo dell'integrale esatto mediante primitiva e dell'errore assoluto
S = feval(funzione,b,1) - feval(funzione,a,1) ;
Err = abs(S-Sn) ;
% Visualizzazione grafica della formula dei trapezi composta
ngrid = 200 ;
t = linspace(a,b,ngrid) ;
for i = 1 : ngrid
f(i) = feval(funzione,t(i)) ;
end
plot(t,f) ;
hold on
for k = 1 : N
fk = feval(funzione,z(k)) ;
fk1 = feval(funzione,z(k+1)) ;
plot([z(k),z(k),z(k+1),z(k+1),z(k)],[0,fk,fk1,0,0]) ;
end
hold off